"""Entry point for python cli."""

from .main import cli

if __name__ == '__main__':
    cli()
